@@ -8,11 +8,14 @@ use super::{
     schema::{Apiv2Errors, Apiv2Operation, Apiv2Schema},
 };
 use crate::util::{ready, Ready};
+#[cfg(feature = "actix3")]
+use actix_web::web::ReqData;
 use actix_web::{
     http::StatusCode,
-    web::{Bytes, Data, Form, Json, Path, Payload, Query, ReqData},
+    web::{Bytes, Data, Form, Json, Path, Payload, Query},
     Error, HttpRequest, HttpResponse, Responder,
 };
+
 use pin_project::pin_project;
 
 use serde::Serialize;
@@ -151,8 +154,10 @@ where
 impl<T> Apiv2Schema for Data<T> {}
 #[cfg(not(feature = "nightly"))]
 impl<T> OperationModifier for Data<T> {}
+#[cfg(feature = "actix3")]
 impl<T: std::clone::Clone> Apiv2Schema for ReqData<T> {}
 #[cfg(not(feature = "nightly"))]
+#[cfg(feature = "actix3")]
 impl<T: std::clone::Clone> OperationModifier for ReqData<T> {}
 
 macro_rules! impl_empty({ $($ty:ty),+ } => {
